@@ -476,7 +476,7 @@ class SegNet(pl.LightningModule):
 
             **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
         """
-        super(ConvNet, self).__init__()
+        super(SegNet, self).__init__()
         
         self.n_classes = n_classes
         self.sample_weight = sample_weight
@@ -501,9 +501,7 @@ class SegNet(pl.LightningModule):
     def reshape_x(self, x_batch):
         dims = x_batch.shape[1:]
         
-        if len(dims) == 1:
-            raise ValueError(f"Wrong dimension {dims} for the input.")
-        elif len(dims) == 2:
+        if len(dims) == 2:
             height = dims[0]
             width = dims[1]
             x_batch = x_batch.reshape(-1, 1, int(height), int(width))
@@ -526,7 +524,7 @@ class SegNet(pl.LightningModule):
     
     def training_step(self, train_batch, batch_idx):
         x_batch, y_batch = train_batch
-        x_batch = self.reshape_x(x_batch)
+        #x_batch = self.reshape_x(x_batch)
         y_batch = self.sample_weight * y_batch
 
         Yhat = self.forward(x_batch)
@@ -549,7 +547,7 @@ class SegNet(pl.LightningModule):
         
     def validation_step(self, val_batch, batch_idx):
         x_batch, y_batch = val_batch
-        x_batch = self.reshape_x(x_batch)
+        #x_batch = self.reshape_x(x_batch)
         Yhat = self.forward(x_batch)
         if self.n_classes is None:
             loss = self.criterion(Yhat.squeeze(), y_batch)
@@ -572,7 +570,7 @@ class SegNet(pl.LightningModule):
 
     def predict_step(self, pred_batch, batch_idx, dataloader_idx=0):
         x_batch, y_batch = pred_batch
-        x_batch = self.reshape_x(x_batch)
+        #x_batch = self.reshape_x(x_batch)
         Yhat = self.forward(x_batch)
         if self.n_classes is None:
             loss = self.criterion(Yhat.squeeze(), y_batch)
@@ -590,7 +588,7 @@ class SegNet(pl.LightningModule):
 
     def test_step(self, test_batch, batch_idx):
         x_batch, y_batch = test_batch
-        x_batch = self.reshape_x(x_batch)
+        #x_batch = self.reshape_x(x_batch)
         Yhat = self.forward(x_batch)
         if self.n_classes is None:
             loss = self.criterion(Yhat.squeeze(), y_batch)
